@@ -131,7 +131,9 @@ type config struct {
 	taskNotificationEnabled bool
 	guestPoliciesEnabled    bool
 	osInventoryEnabled      bool
+	scalibrLinuxEnabled     bool
 	guestAttributesEnabled  bool
+	traceGetInventory       bool
 }
 
 func (c *config) parseFeatures(features string, enabled bool) {
@@ -219,6 +221,8 @@ type attributesJSON struct {
 	OSConfigEnabled       string       `json:"enable-osconfig"`
 	DisabledFeatures      string       `json:"osconfig-disabled-features"`
 	EnableGuestAttributes string       `json:"enable-guest-attributes"`
+	TraceGetInventory     string       `json:"trace-get-inventory"`
+	ScalibrLinuxEnabled   string       `json:"enable-scalibr-linux"`
 }
 
 func createConfigFromMetadata(md metadataJSON) *config {
@@ -349,11 +353,24 @@ func createConfigFromMetadata(md metadataJSON) *config {
 		c.debugEnabled = true
 	}
 
+	setScalibrEnablement(md, c)
 	setSVCEndpoint(md, c)
+	setTraceGetInventory(md, c)
 
 	return c
 }
 
+func setScalibrEnablement(md metadataJSON, c *config) {
+	projectSetting := md.Project.Attributes.ScalibrLinuxEnabled
+	instanceSetting := md.Instance.Attributes.ScalibrLinuxEnabled
+	if projectSetting != "" {
+		c.scalibrLinuxEnabled = parseBool(projectSetting)
+	}
+	if instanceSetting != "" {
+		c.scalibrLinuxEnabled = parseBool(instanceSetting)
+	}
+}
+
 func setSVCEndpoint(md metadataJSON, c *config) {
 	switch {
 	case *endpoint != prodEndpoint:
@@ -374,6 +391,17 @@ func setSVCEndpoint(md metadataJSON, c *config) {
 	c.svcEndpoint = strings.ReplaceAll(c.svcEndpoint, "{zone}", zone)
 }
 
+func setTraceGetInventory(md metadataJSON, c *config) {
+	projectSetting := md.Project.Attributes.TraceGetInventory
+	instanceSetting := md.Instance.Attributes.TraceGetInventory
+	if projectSetting != "" {
+		c.traceGetInventory = parseBool(projectSetting)
+	}
+	if instanceSetting != "" {
+		c.traceGetInventory = parseBool(instanceSetting)
+	}
+}
+
 func formatMetadataError(err error) error {
 	if urlErr, ok := err.(*url.Error); ok {
 		if _, ok := urlErr.Err.(*net.DNSError); ok {
@@ -535,11 +563,21 @@ func DisableLocalLogging() bool {
 	return *disableLocalLogging
 }
 
+// ScalibrLinuxEnabled answers whether scalibr or legacy inventory extractors should be used.
+func ScalibrLinuxEnabled() bool {
+	return getAgentConfig().scalibrLinuxEnabled
+}
+
 // SvcEndpoint is the OS Config service endpoint.
 func SvcEndpoint() string {
 	return getAgentConfig().svcEndpoint
 }
 
+// TraceGetInventory turns on memory tracing while gathering inventory.
+func TraceGetInventory() bool {
+	return getAgentConfig().traceGetInventory
+}
+
 // ZypperRepoDir is the location of the zypper repo files.
 func ZypperRepoDir() string {
 	return zypperRepoDir
