@@ -22,6 +22,7 @@ import (
 	"testing"
 
 	utilmocks "github.com/GoogleCloudPlatform/osconfig/util/mocks"
+	utiltest "github.com/GoogleCloudPlatform/osconfig/util/utiltest"
 	"github.com/golang/mock/gomock"
 )
 
@@ -172,6 +173,7 @@ func TestAptUpdates(t *testing.T) {
 		args                  []AptGetUpgradeOption
 		expectedCommandsChain []expectedCommand
 		expectedResults       []*PkgInfo
+		expectedResultsFile   string
 		expectedError         error
 	}{
 		{
@@ -182,7 +184,7 @@ func TestAptUpdates(t *testing.T) {
 			expectedError:         fmt.Errorf("unknown upgrade type: %q", 10),
 		},
 		{
-			name: "apt-get update",
+			name: "apt-get updates",
 			args: nil,
 			expectedCommandsChain: []expectedCommand{
 				{
@@ -284,6 +286,138 @@ func TestAptUpdates(t *testing.T) {
 			expectedResults: []*PkgInfo{{Name: "google-cloud-sdk", Arch: "x86_64", Version: "246.0.0-0"}},
 			expectedError:   nil,
 		},
+		{
+			name: "debian-10-1 mapped full-upgrade stdout matches snapshot",
+			args: []AptGetUpgradeOption{AptGetUpgradeType(AptGetFullUpgrade)},
+			expectedCommandsChain: []expectedCommand{
+				{
+					cmd:    exec.Command(aptGet, aptGetUpdateArgs...),
+					envs:   []string{"DEBIAN_FRONTEND=noninteractive"},
+					stdout: []byte(""),
+					stderr: []byte(""),
+					err:    nil,
+				},
+				{
+					cmd:    exec.Command(aptGet, append(slices.Clone(aptGetUpgradableArgs), aptGetFullUpgradeCmd)...),
+					envs:   []string{"DEBIAN_FRONTEND=noninteractive"},
+					stdout: utiltest.BytesFromFile(t, "./testdata/debian-10-1.apt-get-full-upgrade.stdout"),
+					stderr: []byte(""),
+					err:    nil,
+				},
+			},
+			expectedResultsFile: "./testdata/debian-10-1.apt-get-full-upgrade.expected",
+			expectedError:       nil,
+		},
+		{
+			name: "debian-11-1 mapped full-upgrade stdout matches snapshot",
+			args: []AptGetUpgradeOption{AptGetUpgradeType(AptGetFullUpgrade)},
+			expectedCommandsChain: []expectedCommand{
+				{
+					cmd:    exec.Command(aptGet, aptGetUpdateArgs...),
+					envs:   []string{"DEBIAN_FRONTEND=noninteractive"},
+					stdout: []byte(""),
+					stderr: []byte(""),
+					err:    nil,
+				},
+				{
+					cmd:    exec.Command(aptGet, append(slices.Clone(aptGetUpgradableArgs), aptGetFullUpgradeCmd)...),
+					envs:   []string{"DEBIAN_FRONTEND=noninteractive"},
+					stdout: utiltest.BytesFromFile(t, "./testdata/debian-11-1.apt-get-full-upgrade.stdout"),
+					stderr: []byte(""),
+					err:    nil,
+				},
+			},
+			expectedResultsFile: "./testdata/debian-11-1.apt-get-full-upgrade.expected",
+			expectedError:       nil,
+		},
+		{
+			name: "debian-12-1 mapped full-upgrade stdout matches snapshot",
+			args: []AptGetUpgradeOption{AptGetUpgradeType(AptGetFullUpgrade)},
+			expectedCommandsChain: []expectedCommand{
+				{
+					cmd:    exec.Command(aptGet, aptGetUpdateArgs...),
+					envs:   []string{"DEBIAN_FRONTEND=noninteractive"},
+					stdout: []byte(""),
+					stderr: []byte(""),
+					err:    nil,
+				},
+				{
+					cmd:    exec.Command(aptGet, append(slices.Clone(aptGetUpgradableArgs), aptGetFullUpgradeCmd)...),
+					envs:   []string{"DEBIAN_FRONTEND=noninteractive"},
+					stdout: utiltest.BytesFromFile(t, "./testdata/debian-12-1.apt-get-full-upgrade.stdout"),
+					stderr: []byte(""),
+					err:    nil,
+				},
+			},
+			expectedResultsFile: "./testdata/debian-12-1.apt-get-full-upgrade.expected",
+			expectedError:       nil,
+		},
+		{
+			name: "ubuntu-20 mapped full-upgrade stdout matches snapshot",
+			args: []AptGetUpgradeOption{AptGetUpgradeType(AptGetFullUpgrade)},
+			expectedCommandsChain: []expectedCommand{
+				{
+					cmd:    exec.Command(aptGet, aptGetUpdateArgs...),
+					envs:   []string{"DEBIAN_FRONTEND=noninteractive"},
+					stdout: []byte(""),
+					stderr: []byte(""),
+					err:    nil,
+				},
+				{
+					cmd:    exec.Command(aptGet, append(slices.Clone(aptGetUpgradableArgs), aptGetFullUpgradeCmd)...),
+					envs:   []string{"DEBIAN_FRONTEND=noninteractive"},
+					stdout: utiltest.BytesFromFile(t, "./testdata/ubuntu-20.apt-get-full-upgrade.stdout"),
+					stderr: []byte(""),
+					err:    nil,
+				},
+			},
+			expectedResultsFile: "./testdata/ubuntu-20.apt-get-full-upgrade.expected",
+			expectedError:       nil,
+		},
+		{
+			name: "ubuntu-22 mapped full-upgrade stdout matches snapshot",
+			args: []AptGetUpgradeOption{AptGetUpgradeType(AptGetFullUpgrade)},
+			expectedCommandsChain: []expectedCommand{
+				{
+					cmd:    exec.Command(aptGet, aptGetUpdateArgs...),
+					envs:   []string{"DEBIAN_FRONTEND=noninteractive"},
+					stdout: []byte(""),
+					stderr: []byte(""),
+					err:    nil,
+				},
+				{
+					cmd:    exec.Command(aptGet, append(slices.Clone(aptGetUpgradableArgs), aptGetFullUpgradeCmd)...),
+					envs:   []string{"DEBIAN_FRONTEND=noninteractive"},
+					stdout: utiltest.BytesFromFile(t, "./testdata/ubuntu-22.apt-get-full-upgrade.stdout"),
+					stderr: []byte(""),
+					err:    nil,
+				},
+			},
+			expectedResultsFile: "./testdata/ubuntu-22.apt-get-full-upgrade.expected",
+			expectedError:       nil,
+		},
+		{
+			name: "ubuntu-24 mapped full-upgrade stdout matches snapshot",
+			args: []AptGetUpgradeOption{AptGetUpgradeType(AptGetFullUpgrade)},
+			expectedCommandsChain: []expectedCommand{
+				{
+					cmd:    exec.Command(aptGet, aptGetUpdateArgs...),
+					envs:   []string{"DEBIAN_FRONTEND=noninteractive"},
+					stdout: []byte(""),
+					stderr: []byte(""),
+					err:    nil,
+				},
+				{
+					cmd:    exec.Command(aptGet, append(slices.Clone(aptGetUpgradableArgs), aptGetFullUpgradeCmd)...),
+					envs:   []string{"DEBIAN_FRONTEND=noninteractive"},
+					stdout: utiltest.BytesFromFile(t, "./testdata/ubuntu-24.apt-get-full-upgrade.stdout"),
+					stderr: []byte(""),
+					err:    nil,
+				},
+			},
+			expectedResultsFile: "./testdata/ubuntu-24.apt-get-full-upgrade.expected",
+			expectedError:       nil,
+		},
 		{
 			name: "Default upgrade type with showNew equals true",
 			args: []AptGetUpgradeOption{AptGetUpgradeShowNew(true)},
@@ -385,8 +519,10 @@ func TestAptUpdates(t *testing.T) {
 				t.Errorf("AptUpdates: unexpected error, expect %q, got %q", formatError(tt.expectedError), formatError(err))
 			}
 
-			if !reflect.DeepEqual(pkgs, tt.expectedResults) {
-				t.Errorf("AptUpdates: unexpected result, expect %v, got %v", pkgs, tt.expectedResults)
+			if tt.expectedResultsFile != "" {
+				utiltest.MatchSnapshot(t, pkgs, tt.expectedResultsFile)
+			} else if !reflect.DeepEqual(pkgs, tt.expectedResults) {
+				t.Errorf("AptUpdates: unexpected result, expect %v, got %v", tt.expectedResults, pkgs)
 			}
 		})
 	}
@@ -510,31 +646,136 @@ func TestRemoveAptPackages(t *testing.T) {
 }
 
 func TestInstalledDebPackages(t *testing.T) {
-	mockCtrl := gomock.NewController(t)
-	defer mockCtrl.Finish()
-	mockCommandRunner := utilmocks.NewMockCommandRunner(mockCtrl)
-	runner = mockCommandRunner
-
-	//Successfully returns result
-	dpkgQueryCmd := utilmocks.EqCmd(exec.Command(dpkgQuery, dpkgQueryArgs...))
-	stdout := []byte(`{"package":"git","architecture":"amd64","version":"1:2.25.1-1ubuntu3.12","status":"installed","source_name":"git","source_version":"1:2.25.1-1ubuntu3.12"}`)
-	stderr := []byte("stderr")
-	mockCommandRunner.EXPECT().Run(testCtx, dpkgQueryCmd).Return(stdout, stderr, nil).Times(1)
-
-	result, err := InstalledDebPackages(testCtx)
-	if err != nil {
-		t.Errorf("InstalledDebPackages(): got unexpected error: %v", err)
+	tests := []struct {
+		name             string
+		cmds             []expectedCommand
+		wantErr          error
+		wantPkgs         []*PkgInfo
+		wantPkgsSnapshot string
+	}{
+		{
+			name: "single entry maps to package",
+			cmds: []expectedCommand{
+				{
+					cmd:    exec.Command(dpkgQuery, dpkgQueryArgs...),
+					stdout: []byte(`{"package":"git","architecture":"amd64","version":"1:2.25.1-1ubuntu3.12","status":"installed","source_name":"git","source_version":"1:2.25.1-1ubuntu3.12"}`),
+					stderr: []byte(""),
+				},
+			},
+			wantPkgs: []*PkgInfo{{Name: "git", Arch: "x86_64", Version: "1:2.25.1-1ubuntu3.12", Source: Source{Name: "git", Version: "1:2.25.1-1ubuntu3.12"}}},
+		},
+		{
+			name: "empty package list maps to nil",
+			cmds: []expectedCommand{
+				{
+					cmd:    exec.Command(dpkgQuery, dpkgQueryArgs...),
+					stdout: []byte(""),
+					stderr: []byte(""),
+				},
+			},
+			wantPkgs: nil,
+		},
+		{
+			name: "non-zero exit code propagates as error",
+			cmds: []expectedCommand{
+				{
+					cmd:    exec.Command(dpkgQuery, dpkgQueryArgs...),
+					stdout: []byte(""),
+					stderr: []byte("stderr"),
+					err:    errors.New("error"),
+				},
+			},
+			wantErr: fmt.Errorf("error running %s with args %q: %v, stdout: %q, stderr: %q", dpkgQuery, dpkgQueryArgs, errors.New("error"), []byte(""), []byte("stderr")),
+		},
+		{
+			name: "debian-10-1 mapped stdout matches snapshot",
+			cmds: []expectedCommand{
+				{
+					cmd:    exec.Command(dpkgQuery, dpkgQueryArgs...),
+					stdout: utiltest.BytesFromFile(t, "./testdata/debian-10-1.dpkg-query-show.stdout"),
+					stderr: []byte(""),
+				},
+			},
+			wantPkgsSnapshot: "./testdata/debian-10-1.dpkg-query-show.want",
+		},
+		{
+			name: "debian-11-1 mapped stdout matches snapshot",
+			cmds: []expectedCommand{
+				{
+					cmd:    exec.Command(dpkgQuery, dpkgQueryArgs...),
+					stdout: utiltest.BytesFromFile(t, "./testdata/debian-11-1.dpkg-query-show.stdout"),
+					stderr: []byte(""),
+				},
+			},
+			wantPkgsSnapshot: "./testdata/debian-11-1.dpkg-query-show.want",
+		},
+		{
+			name: "debian-12-1 mapped stdout matches snapshot",
+			cmds: []expectedCommand{
+				{
+					cmd:    exec.Command(dpkgQuery, dpkgQueryArgs...),
+					stdout: utiltest.BytesFromFile(t, "./testdata/debian-12-1.dpkg-query-show.stdout"),
+					stderr: []byte(""),
+				},
+			},
+			wantPkgsSnapshot: "./testdata/debian-12-1.dpkg-query-show.want",
+		},
+		{
+			name: "ubuntu-20-1 mapped stdout matches snapshot",
+			cmds: []expectedCommand{
+				{
+					cmd:    exec.Command(dpkgQuery, dpkgQueryArgs...),
+					stdout: utiltest.BytesFromFile(t, "./testdata/ubuntu-20-1.dpkg-query-show.stdout"),
+					stderr: []byte(""),
+				},
+			},
+			wantPkgsSnapshot: "./testdata/ubuntu-20-1.dpkg-query-show.want",
+		},
+		{
+			name: "ubuntu-22-1 mapped stdout matches snapshot",
+			cmds: []expectedCommand{
+				{
+					cmd:    exec.Command(dpkgQuery, dpkgQueryArgs...),
+					stdout: utiltest.BytesFromFile(t, "./testdata/ubuntu-22-1.dpkg-query-show.stdout"),
+					stderr: []byte(""),
+				},
+			},
+			wantPkgsSnapshot: "./testdata/ubuntu-22-1.dpkg-query-show.want",
+		},
+		{
+			name: "ubuntu-24-1 mapped stdout matches snapshot",
+			cmds: []expectedCommand{
+				{
+					cmd:    exec.Command(dpkgQuery, dpkgQueryArgs...),
+					stdout: utiltest.BytesFromFile(t, "./testdata/ubuntu-24-1.dpkg-query-show.stdout"),
+					stderr: []byte(""),
+				},
+			},
+			wantPkgsSnapshot: "./testdata/ubuntu-24-1.dpkg-query-show.want",
+		},
 	}
 
-	want := []*PkgInfo{{Name: "git", Arch: "x86_64", Version: "1:2.25.1-1ubuntu3.12", Source: Source{Name: "git", Version: "1:2.25.1-1ubuntu3.12"}}}
-	if !reflect.DeepEqual(result, want) {
-		t.Errorf("InstalledDebPackages() = %v, want %v", result, want)
-	}
+	for _, tt := range tests {
+		mockCtrl := gomock.NewController(t)
+		defer mockCtrl.Finish()
 
-	//Returns error if any
-	mockCommandRunner.EXPECT().Run(testCtx, dpkgQueryCmd).Return(stdout, stderr, errors.New("error")).Times(1)
-	if _, err := InstalledDebPackages(testCtx); err == nil {
-		t.Errorf("did not get expected error")
+		mockCommandRunner := utilmocks.NewMockCommandRunner(mockCtrl)
+		runner = mockCommandRunner
+
+		t.Run(tt.name, func(t *testing.T) {
+			setExpectations(mockCommandRunner, tt.cmds)
+
+			pkgs, err := InstalledDebPackages(testCtx)
+			if !reflect.DeepEqual(err, tt.wantErr) {
+				t.Errorf("InstalledDebPackages err: want %v, got %v", tt.wantErr, err)
+			}
+
+			if tt.wantPkgsSnapshot != "" {
+				utiltest.MatchSnapshot(t, pkgs, tt.wantPkgsSnapshot)
+			} else if !reflect.DeepEqual(pkgs, tt.wantPkgs) {
+				t.Errorf("InstalledDebPackages pkgs: want %v, got %v", tt.wantPkgs, pkgs)
+			}
+		})
 	}
 }
 
