@@ -23,6 +23,7 @@ import (
 	"strings"
 
 	"github.com/GoogleCloudPlatform/osconfig/clog"
+	"github.com/GoogleCloudPlatform/osconfig/osinfo"
 	"github.com/GoogleCloudPlatform/osconfig/util"
 	ole "github.com/go-ole/go-ole"
 )
@@ -61,7 +62,7 @@ func wuaUpdates(ctx context.Context, query string) ([]*WUAPackage, error) {
 
 // GetPackageUpdates gets available package updates GooGet as well as any
 // available updates from Windows Update Agent.
-func GetPackageUpdates(ctx context.Context) (*Packages, error) {
+func GetPackageUpdates(ctx context.Context) (Packages, error) {
 	var pkgs Packages
 	var errs []string
 
@@ -89,12 +90,12 @@ func GetPackageUpdates(ctx context.Context) (*Packages, error) {
 	if len(errs) != 0 {
 		err = errors.New(strings.Join(errs, "\n"))
 	}
-	return &pkgs, err
+	return pkgs, err
 }
 
 // GetInstalledPackages gets all installed GooGet packages and Windows updates.
 // Windows updates are read from Windows Update Agent and Win32_QuickFixEngineering.
-func GetInstalledPackages(ctx context.Context) (*Packages, error) {
+func GetInstalledPackages(ctx context.Context) (Packages, error) {
 	var pkgs Packages
 	var errs []string
 
@@ -139,5 +140,10 @@ func GetInstalledPackages(ctx context.Context) (*Packages, error) {
 	if len(errs) != 0 {
 		err = errors.New(strings.Join(errs, "\n"))
 	}
-	return &pkgs, err
+	return pkgs, err
+}
+
+// NewInstalledPackagesProvider returns fully initialized provider.
+func NewInstalledPackagesProvider(_ osinfo.Provider) InstalledPackagesProvider {
+	return defaultInstalledPackagesProvider{}
 }
